@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1992 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1992 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -27,24 +27,16 @@
 
 /* Methods string infix calculator file for Abacus */
 
-#ifdef WINVER
 #include "AbacusP.h"
-#else
-#include <stdlib.h>
-#include <stdio.h>
-#ifdef VMS
-#include <unixlib.h>
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
+#ifndef WINVER
 #include <math.h>
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
-#include "AbacusP.h"
+#ifndef M_PI
+#define M_PI 3.14159265358979323846
+#endif
+#ifndef M_E
+#define M_E 2.7182818284590452354
+extern int signgam;
+#endif
 #endif
 
 /* proposed, implemented only a small portion
@@ -230,7 +222,7 @@ static const short unsigned int operationASCII[] =
 };
 
 #define CHAR_TO_DIGIT(c) ((c >= 'A') ? c - 'A' + 10 : c - '0')
-#define DIGIT_TO_CHAR(d) ((d >= 10) ? 'A' + d - 10 : '0' + d)
+#define DIGIT_TO_CHAR(d) ((d >= 10) ? (char) ('A' + d - 10) : (char) ('0' + d))
 #define IS_DIGIT(c) ((c >= '0' && c <= '9') || (c >= 'A' && c <= 'F'))
 /* True for period, +/-, or operator */
 #define IS_VALID(v, b) ((IS_DIGIT(v)) ? (CHAR_TO_DIGIT(v) < b) : True)
@@ -259,7 +251,7 @@ static Term *term;
 static Expression *expression;
 
 #define DEFAULTBASE 10
-#define DEFAULTFRACTDIGITS 8
+#define DEFAULTFRACTDIGITS 16
 
 /* Inputter & Parser & Paren Manager */
 static Boolean period = False;
@@ -378,7 +370,7 @@ convertToDecimal(int b, char *inputstring)
 }
 
 static void
-convertFromDecimal(char *outputstring, int b, double x)
+convertFromDecimal(char *outputString, int b, double x)
 {
 	char string[MAXVALUELENGTH];
 	Boolean localPeriod = False;
@@ -391,7 +383,7 @@ convertFromDecimal(char *outputstring, int b, double x)
 
 	(void) sprintf(string, "%g", x);
 	if (string[i] == '-') {
-		outputstring[l++] = '-';
+		outputString[l++] = '-';
 		x = -x;
 	}
 	while (string[i] != '\0') {
@@ -410,34 +402,34 @@ convertFromDecimal(char *outputstring, int b, double x)
 		number = x;
 		/* Convert Integer Part */
 		if (number < 1.0) {
-			outputstring[l++] = '0';
+			outputString[l++] = '0';
 			factor = 1.0 / ((double) b);
 		} else {
 			places_base = logInt(number, b);
 			factor = pow((double) b, (double) places_base);
 			for (; places_base >= 0; places_base--) {
 				digit = (int) (number / factor);
-				outputstring[l++] = DIGIT_TO_CHAR(digit);
+				outputString[l++] = DIGIT_TO_CHAR(digit);
 				number -= digit * factor;
 				factor /= ((double) b);
 			}
 		}
 		/* Convert Fractional Part */
 		if (localPeriod) {
-			outputstring[l++] = '.';
+			outputString[l++] = '.';
 			for (places_base = 1; places_base <= fractdigits;
 					places_base++) {
 				digit = (int) (number / factor);
-				outputstring[l++] = DIGIT_TO_CHAR(digit);
+				outputString[l++] = DIGIT_TO_CHAR(digit);
 				number -= digit * factor;
 				factor /= ((double) b);
 			}
-			while (outputstring[l - 1] == '0')
+			while (outputString[l - 1] == '0')
 				l--;
 		}
 	}
 
-	outputstring[l] = '\0';
+	outputString[l] = '\0';
 }
 
 static double
@@ -490,8 +482,7 @@ formatToDisplay (char *string, double z)
 	while (i <= length) {
 		if (string[i] == '\0' && periods == 0) {
 			j = length;
-			while (j >= i)
-			{
+			while (j >= i) {
 				string[j + 1] = string[j];
 				j--;
 			}
@@ -775,8 +766,9 @@ static Boolean evaluateExpressionOrder(double *myLeft, char *binaryOperation,
 			if (pushStack(*myLeft, *binaryOperation, order)) {
 				*myLeft = *myRight;
 				return True;
-			} else
+			} else {
 				return False;
+			}
 		}
 	} else
 		*myLeft = *myRight;
@@ -801,7 +793,7 @@ static void evaluateExpression(double *myLeft, char *binaryOperation)
 	while (!emptyExpression()) {
 		myRight = *myLeft;
 		getPreviousExpressionPart(myLeft, binaryOperation);
-		if (binaryOperation != NULL)
+		if (binaryOperation != '\0')
 			*myLeft = evaluateDouble(*myLeft, *binaryOperation,
 				myRight);
 		else
@@ -1045,7 +1037,8 @@ convertStringToAbacus(AbacusWidget w, char *string)
 		SetAbacusMove(w, ABACUS_MOVE, 0, 0, w->abacus.rails -
 			w->abacus.decimalPosition - 1, 1);
 	}
-	for (i = 0; i < len - decimal - 1; i++) {
+	for (i = 0; i < len - decimal - 1 &&
+			i < w->abacus.decimalPosition; i++) {
 		num = char2Int(string[decimal + i + 1]);
 		factor = num / w->abacus.decks[TOP].factor;
 		if (factor > 0) {
@@ -1065,6 +1058,9 @@ void calculate(AbacusWidget w, char * buffer)
 
 	if (w->abacus.displayBase != w->abacus.base)
 		return;
+	currentBase = w->abacus.displayBase;
+	fractDigits = logInt(powInt(DEFAULTBASE, DEFAULTFRACTDIGITS),
+		currentBase);
 	resetExpression();
 	memoryBuf[0] = '0';
 	memoryBuf[1] = '\0';
