@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1999 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1999 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #  Abacus demo and neat pointers from
 #  Copyright (c) 1991 - 1998	Luis Fernandes, elf@ee.ryerson.ca
@@ -28,24 +28,9 @@
 
 /* Methods demo file for Abacus */
 
-#if WINVER
-#include "AbacusP.h"
-#else
-#include <stdlib.h>
-#include <stdio.h>
-#ifdef VMS
-#include <unixlib.h>
-#else
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif
-#include <X11/IntrinsicP.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
-#include <X11/CoreP.h>
 #include "AbacusP.h"
 
+#ifndef WINVER
 static void InitializeAbacusDemo(Widget request, Widget renew);
 static void ExposeAbacusDemo(Widget renew, XEvent * event, Region region);
 
@@ -117,7 +102,7 @@ static XtResource resourcesAbacusDemo[] =
 	{XtNdemoPath, XtCDemoPath, XtRString, sizeof (String),
 	 XtOffset(AbacusWidget, abacusDemo.path),
 	 XtRString, (caddr_t) DEMOPATH},
-	{XtNdemoFont, XtCDemoFont, XtRString, sizeof (String),
+	{XtNdemoFont, XtCFont, XtRString, sizeof (String),
 	 XtOffset(AbacusWidget, abacusDemo.font),
 	 XtRString, (caddr_t) "-*-times-*-r-*-*-*-180-*-*-*-*"},
 	{XtNdemoForeground, XtCForeground, XtRPixel, sizeof (Pixel),
@@ -146,7 +131,7 @@ static XtResource resourcesAbacusDemo[] =
 	 XtRCallback, (caddr_t) NULL}
 };
 
-AbacusClassRec abacusDemoClassRec =
+static AbacusClassRec abacusDemoClassRec =
 {
 	{
 		(WidgetClass) & widgetClassRec,		/* superclass */
@@ -241,6 +226,9 @@ SetAllColors(AbacusWidget w, Boolean init)
 	if (!init)
 		XtReleaseGC((Widget) w, w->abacusDemo.inverseGC);
 	w->abacusDemo.inverseGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->abacusDemo.fontInfo)
+                XSetFont(XtDisplay(w), w->abacusDemo.foregroundGC,
+			w->abacusDemo.fontInfo->fid);
 }
 
 static void
@@ -275,9 +263,9 @@ loadFont(AbacusWidget w)
 
 typedef enum {
 	INTRO, QUERY, DISPLAY, CONCL
-} texttypes;
+} TextType;
 
-static const char *introframelesstext[LINES] =
+static const char *introFramelessText[LINES] =
 {
 	"Place this window below the abacus, then click & leave",
 	"the pointer in the abacus window to begin the demo.",
@@ -285,7 +273,7 @@ static const char *introframelesstext[LINES] =
 	"Type `q' to quit the demo.",
 };
 
-static const char *introframedtext[LINES] =
+static const char *introFramedText[LINES] =
 {
 	"Click & leave the pointer in the abacus window",
 	"to begin the demo.",
@@ -293,7 +281,7 @@ static const char *introframedtext[LINES] =
 	"Type `q' to quit the demo.",
 };
 
-static const char *querytext[LINES] =
+static const char *queryText[LINES] =
 {
 	"Type:",
 	"  `n' for the Next lesson",
@@ -301,7 +289,7 @@ static const char *querytext[LINES] =
 	"  `q' to Quit the demo",
 };
 
-static const char *concltext[LINES] =
+static const char *conclText[LINES] =
 {
 	"Here Endth The Lesson",
 	"",
@@ -312,20 +300,22 @@ static const char *concltext[LINES] =
 /* This array represents 4 lines of text that are to be displayed in the
  * demo window; the module drawDemoWindow() will be passed a pointer to this
  * array */
-static char displaytext[LINES][CHARS];
+static char displayText[LINES][CHARS];
 
 static void
-drawText(AbacusWidget w, texttypes textt)
+drawText(AbacusWidget w, TextType textType)
 {
-	int         line;
 	static Boolean firstTime = True;
+	int line;
+	Pixmap dr = 0;
+
 	if (!firstTime) {
 #ifdef WINVER
-		FILLRECTANGLE(w, w->abacus.inverseGC,
+		FILLRECTANGLE(w, dr, w->abacus.inverseGC,
 			0, w->core.height, w->core.width,
 			w->core.height + LINES * w->abacusDemo.fontHeight - 1);
 #else
-		FILLRECTANGLE(w, w->abacusDemo.inverseGC,
+		FILLRECTANGLE(w, dr, w->abacusDemo.inverseGC,
 			0, 0, w->core.width, w->core.height);
 #endif
 	} else {
@@ -335,69 +325,79 @@ drawText(AbacusWidget w, texttypes textt)
 	for (line = 0; line < w->abacusDemo.lines; line++) {
 		const char * temp;
 
-		switch (textt) {
+		switch (textType) {
 			case INTRO:
 				if (w->abacusDemo.framed)
-					temp = introframedtext[line];
+					temp = introFramedText[line];
 				else
-					temp = introframelesstext[line];
+					temp = introFramelessText[line];
 #ifdef DEBUG
 				(void) fprintf(stderr, " INTRO\n");
 #endif
 				break;
 			case CONCL:
 				w->abacusDemo.started = False;
-				temp = concltext[line];
+				temp = conclText[line];
 #ifdef DEBUG
 				(void) fprintf(stderr, " CONCL\n");
 #endif
 				break;
 			case QUERY:
 				w->abacusDemo.query = True;
-				temp = querytext[line];
+				temp = queryText[line];
 #ifdef DEBUG
 				(void) fprintf(stderr, " QUERY\n");
 #endif
 				break;
 			default:
-				temp = displaytext[line];
+				temp = displayText[line];
 #ifdef DEBUG
 				(void) fprintf(stderr, " DISPLAY\n");
 #endif
 				break;
 		}
 #ifdef DEBUG
-		(void) printf("%d, %d %s\n", w->abacusDemo.fontHeight, line, temp);
+		(void) printf("%d, %d %s\n",
+			      w->abacusDemo.fontHeight, line, temp);
 #endif
 #ifdef WINVER
 		(void) SetTextColor(w->core.hDC, w->abacusDemo.foregroundGC);
 		(void) SetBkMode(w->core.hDC, TRANSPARENT);
 		(void) TextOut(w->core.hDC,
-			1, w->core.height + w->abacusDemo.fontHeight * line - 1,
+			1,
+			w->core.height + w->abacusDemo.fontHeight * line - 1,
 			temp, (signed) strlen(temp));
 #else
 		(void) XDrawString(XtDisplay(w), XtWindow(w),
 			w->abacusDemo.foregroundGC,
-			1, w->abacusDemo.fontHeight + (w->abacusDemo.fontHeight * line),
+			1, w->abacusDemo.fontHeight +
+			(w->abacusDemo.fontHeight * line),
 			temp, strlen(temp));
 		XFlush(XtDisplay(w));
 #endif
 	}
 }
 
-char *
+static char *
 postfixType(int mode)
 {
 	switch (mode) {
-	case CHINESE: return "";
-	case JAPANESE: return "jp";
-	case KOREAN: return "ko";
-	case ROMAN: return "jp"; /* ro */
-	case RUSSIAN: return "ru";
-	default: return "err";
+		case CHINESE:
+			return (char *) ""; /* cn */
+		case JAPANESE:
+			return (char *) "jp";
+		case KOREAN:
+			return (char *) "ko";
+		case ROMAN:
+			return (char *) "jp"; /* ro */
+		case RUSSIAN:
+			return (char *) "ru";
+		default:
+			return (char *) "err";
 	}
 }
 
+#ifndef WINVER
 /* Find the lessons... this way its easy to add more */
 static void
 setLessons(AbacusWidget w)
@@ -411,7 +411,7 @@ setLessons(AbacusWidget w)
 			FINALDELIM, postfixType(w->abacus.mode),
 			w->abacusDemo.lessons);
 		if ((w->abacusDemo.fp = fopen(fname, "r")) == NULL) {
-			/* Try current directory in case its not installed yet. */
+			/* Try current directory in case its not installed. */
 			(void) sprintf(lname, "%sAbacus%s%d.les", CURRENTDELIM,
 				postfixType(w->abacus.mode),
 				w->abacusDemo.lessons);
@@ -427,6 +427,7 @@ setLessons(AbacusWidget w)
 		(void) fclose(w->abacusDemo.fp);
 	}
 }
+#endif
 
 static void
 startLesson(AbacusWidget w)
@@ -442,7 +443,7 @@ startLesson(AbacusWidget w)
 #endif
 	if ((w->abacusDemo.fp = fopen(fname, "r")) == NULL) {
 
-		/* Try current directory in case its not installed yet. */
+		/* Try current directory in case its not installed. */
 		(void) sprintf(lname, "%sAbacus%s%d.les", CURRENTDELIM,
 		       postfixType(w->abacus.mode),
 		       w->abacusDemo.lessonCount + 1);
@@ -460,11 +461,12 @@ startLesson(AbacusWidget w)
 		  &(w->abacusDemo.number), &(w->abacusDemo.lines)) > 0) {
 		int         line;
 
-		if  (w->abacusDemo.lines > LINES)
+		if (w->abacusDemo.lines > LINES)
 			w->abacusDemo.lines = LINES;
 		for (line = 0; line < w->abacusDemo.lines; line++) {
-			(void) fgets(displaytext[line], 64, w->abacusDemo.fp);
-			displaytext[line][strlen(displaytext[line]) - 1] = '\0';
+			(void) fgets(displayText[line], 64, w->abacusDemo.fp);
+			displayText[line][strlen(displayText[line]) - 1] =
+				'\0';
 		}
 		++w->abacusDemo.lessonLength;
 	}
@@ -498,17 +500,18 @@ doLesson(AbacusWidget w)
 		&(w->abacusDemo.deck), &(w->abacusDemo.rail),
 		&(w->abacusDemo.number), &(w->abacusDemo.lines));
 #ifdef DEBUG
-	(void) printf("aux %d, deck = %d, rail = %d, number = %d, lines = %d\n",
+	(void) printf(
+		"aux %d, deck = %d, rail = %d, number = %d, lines = %d\n",
 		w->abacusDemo.aux,
 		w->abacusDemo.deck, w->abacusDemo.rail,
 		w->abacusDemo.number, w->abacusDemo.lines);
 #endif
 
-	if  (w->abacusDemo.lines > LINES)
+	if (w->abacusDemo.lines > LINES)
 		w->abacusDemo.lines = LINES;
 	for (line = 0; line < w->abacusDemo.lines; line++) {
-		(void) fgets(displaytext[line], 64, w->abacusDemo.fp);
-		displaytext[line][strlen(displaytext[line]) - 1] = '\0';
+		(void) fgets(displayText[line], 64, w->abacusDemo.fp);
+		displayText[line][strlen(displayText[line]) - 1] = '\0';
 	}
 
 	/* A '0' in demo number signifies that only the text is to be
@@ -520,26 +523,28 @@ doLesson(AbacusWidget w)
 			w->abacusDemo.deck, w->abacusDemo.rail,
 			w->abacusDemo.number);
 	}
-	drawText(w, DISPLAY);
-
 	if (--w->abacusDemo.lessonLength < 0) {
 		(void) fclose(w->abacusDemo.fp);
 		w->abacusDemo.lines = LINES;
 		drawText(w, CONCL);
 		Sleep(1000);
 		drawText(w, QUERY);
+	} else {
+		drawText(w, DISPLAY);
 	}
 }
 
+#ifndef WINVER
 static void
-ClearDemo(AbacusWidget w)
+clearDemo(AbacusWidget w)
 {
         SetAbacusDemo(w, ABACUS_CLEAR);
 	ClearAbacusDemo(w);
 }
+#endif
 
 static void
-QueryDemo(AbacusWidget w, Boolean advance)
+queryDemo(AbacusWidget w, Boolean advance)
 {
 	if (w->abacusDemo.query) {
 		w->abacusDemo.started = True;
@@ -558,7 +563,7 @@ QueryDemo(AbacusWidget w, Boolean advance)
 }
 
 static void
-IncDemo(AbacusWidget w)
+incDemo(AbacusWidget w)
 {
 	if (w->abacusDemo.started && !w->abacusDemo.query) {
 		w->abacusDemo.query = False;
@@ -583,8 +588,8 @@ InitializeAbacusDemo(
 
 	w->abacus.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->abacus.mono);
-	SetAllColors(w, True);
 	loadFont(w);
+	SetAllColors(w, True);
 #if 0
 	ResizeAbacusDemo(w);
 #endif
@@ -605,15 +610,13 @@ SetValuesAbacusDemo(Widget current, Widget request, Widget renew)
 {
 	AbacusWidget c = (AbacusWidget) current, w = (AbacusWidget) renew;
 	Boolean     redraw = False;
-
 #if 0
 	Boolean     redrawText = False;
-
 #endif
 
 	if (w->abacus.mode != c->abacus.mode) {
 		setLessons(w);
-		ClearAbacusDemo(w);
+		redraw = True;
 	}
 	if (w->core.background_pixel != c->core.background_pixel ||
 	    w->abacus.foreground != c->abacus.foreground ||
@@ -634,19 +637,19 @@ SetValuesAbacusDemo(Widget current, Widget request, Widget renew)
 #endif
 	if (w->abacus.deck == ABACUS_CLEAR) {
 		w->abacus.deck = ABACUS_IGNORE;
-		ClearDemo(w);
+		clearDemo(w);
 	}
 	if (w->abacus.deck == ABACUS_NEXT) {
 		w->abacus.deck = ABACUS_IGNORE;
-		QueryDemo(w, True);
+		queryDemo(w, True);
 	}
 	if (w->abacus.deck == ABACUS_REPEAT) {
 		w->abacus.deck = ABACUS_IGNORE;
-		QueryDemo(w, False);
+		queryDemo(w, False);
 	}
 	if (w->abacus.deck == ABACUS_MORE) {
 		w->abacus.deck = ABACUS_IGNORE;
-		IncDemo(w);
+		incDemo(w);
 	}
 	return (redraw);
 }
@@ -699,8 +702,10 @@ Widget renew, XEvent * event, Region region
 #endif
 )
 {
+	Pixmap dr = 0;
+
 #ifdef WINVER
-	FILLRECTANGLE(w, w->abacus.inverseGC,
+	FILLRECTANGLE(w, dr, w->abacus.inverseGC,
 		0, w->core.height, w->core.width,
 		w->core.height + LINES * w->abacusDemo.fontHeight - 1);
 #else
@@ -708,7 +713,7 @@ Widget renew, XEvent * event, Region region
 
 	if (!w->core.visible)
 		return;
-	FILLRECTANGLE(w, w->abacusDemo.inverseGC,
+	FILLRECTANGLE(w, dr, w->abacusDemo.inverseGC,
 		0, 0, w->core.width, w->core.height);
 #endif
 	if (w->abacusDemo.started) {
@@ -724,29 +729,23 @@ Widget renew, XEvent * event, Region region
 
 #ifndef WINVER
 static
-#endif
 void
 HideAbacusDemo(AbacusWidget w
-#ifndef WINVER
 , XEvent * event, char **args, int nArgs
-#endif
 	)
 {
         SetAbacusDemo(w, ABACUS_HIDE);
 }
 
-#ifndef WINVER
 static
-#endif
 void
 SelectAbacusDemo(AbacusWidget w
-#ifndef WINVER
 , XEvent * event, char **args, int nArgs
-#endif
 	)
 {
-	ClearDemo(w);
+	clearDemo(w);
 }
+#endif
 
 #ifndef WINVER
 static
@@ -774,7 +773,6 @@ DemoAbacusDemo(AbacusWidget w
 	w->abacus.demo = !w->abacus.demo;
 	if (w->abacus.demo)
         	SetAbacusDemo(w, ABACUS_DEMO_DEFAULT);
-			
 #else
         SetAbacusDemo(w, ABACUS_DEMO);
 #endif
@@ -790,7 +788,7 @@ NextAbacusDemo(AbacusWidget w
 #endif
 	)
 {
-	QueryDemo(w, True);
+	queryDemo(w, True);
 }
 
 #ifndef WINVER
@@ -803,7 +801,7 @@ RepeatAbacusDemo(AbacusWidget w
 #endif
 	)
 {
-	QueryDemo(w, False);
+	queryDemo(w, False);
 }
 
 #ifndef WINVER
@@ -816,5 +814,5 @@ MoreAbacusDemo(AbacusWidget w
 #endif
 	)
 {
-	IncDemo(w);
+	incDemo(w);
 }
