@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1996 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -36,6 +36,9 @@
 #define IDM_QUARTER	206
 #define IDM_QUARTERPERCENT	207
 #define IDM_VERTICAL	208
+#define IDM_SPEED	209
+#define IDM_SLOW	210
+#define IDM_SOUND	211
 #define IDM_DEMO	300
 #define IDM_NEXT	301
 #define IDM_REPEAT	302
